/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.server.actions;

import org.ogf.graap.wsag.api.AgreementFactoryContext;
import org.ogf.graap.wsag.server.engine.WsagEngine;
import org.ogf.graap.wsag4j.types.configuration.ImplementationConfigurationType;

/**
 * Defines an agreement factory action. An agreement factory action is an action that is executed by an
 * agreement factory. This can be the creation of an agreement template, the instantiation of an agreement, or
 * the negotiation of an offer.
 * 
 * @see AbstractGetTemplateAction
 * @see AbstractNegotiationAction
 * @see AbstractCreateAgreementAction
 * 
 * @author Oliver Waeldrich
 * 
 */
public interface IAction
{

    /**
     * Initializes the action.
     * 
     * @throws Exception
     *             indicates an error during the initialization of this action. This causes that the action is
     *             not loaded by the system.
     */
    void initialize() throws Exception;

    /**
     * 
     * @return the agreement factory context of this action
     */
    AgreementFactoryContext getFactoryContext();

    /**
     * 
     * @param context
     *            sets the agreement factory context of this action
     */
    void setFactoryContext( AgreementFactoryContext context );

    /**
     * 
     * @return configuration of an action
     */
    ImplementationConfigurationType getActionConfiguration();

    /**
     * 
     * @param configuration
     *            configuration of an action
     */
    void setActionConfiguration( ImplementationConfigurationType configuration );

    /**
     * Returns the WSAG4J engine instance for this handler.
     * 
     * @return the engine instance
     */
    WsagEngine getEngine();

    /**
     * Sets the WSAG4J engine instance for this handler.
     * 
     * @param engine
     *            the engine instance
     */
    void setEngine( WsagEngine engine );
}
